pub struct Generics<'db> {
chain: ArrayVec<SingleGenerics<'db>, 2>,
}Fields
chain: ArrayVec<SingleGenerics<'db>, 2>Implementations
Sourceimpl<'db> Generics<'db>
impl<'db> Generics<'db>
pub(crate) fn iter_owners( &self, ) -> impl DoubleEndedIterator<Item = &SingleGenerics<'db>>
pub(crate) fn owner(&self) -> &SingleGenerics<'db>
pub(crate) fn parent(&self) -> Option<&SingleGenerics<'db>>
pub(crate) fn has_no_params(&self) -> bool
pub(crate) fn def(&self) -> GenericDefId
pub(crate) fn store(&self) -> &'db ExpressionStore
pub(crate) fn iter_self( &self, ) -> impl Iterator<Item = (GenericParamId, GenericParamDataRef<'db>)>
pub(crate) fn iter_self_with_idx( &self, ) -> impl Iterator<Item = (u32, GenericParamId, GenericParamDataRef<'db>)>
pub(crate) fn iter_self_late_bound( &self, ) -> impl Iterator<Item = (GenericParamId, GenericParamDataRef<'db>)>
pub(crate) fn iter_parent_id(&self) -> impl Iterator<Item = GenericParamId>
pub(crate) fn iter_self_type_or_consts( &self, ) -> impl Iterator<Item = (TypeOrConstParamId, &'db TypeOrConstParamData)>
Sourcepub(crate) fn iter(
&self,
consider_late_bound: bool,
) -> impl Iterator<Item = (GenericParamId, GenericParamDataRef<'db>)>
pub(crate) fn iter( &self, consider_late_bound: bool, ) -> impl Iterator<Item = (GenericParamId, GenericParamDataRef<'db>)>
Iterate over the parent params followed by self params.
pub(crate) fn iter_id( &self, consider_late_bound: bool, ) -> impl Iterator<Item = GenericParamId>
Sourcepub(crate) fn len(&self, consider_late_bound: bool) -> usize
pub(crate) fn len(&self, consider_late_bound: bool) -> usize
Returns total number of generic parameters in scope, including those from parent.
pub(crate) fn len_parent(&self) -> usize
pub(crate) fn len_lifetimes_self(&self) -> usize
pub(crate) fn provenance_split(&self) -> ProvenanceSplit
fn find_owner(&self, def: GenericDefId) -> &SingleGenerics<'db>
pub(crate) fn type_or_const_param_idx(&self, param: TypeOrConstParamId) -> u32
pub(crate) fn lifetime_param_idx( &self, param: LifetimeParamId, is_lowering_impl_trait_bounds: bool, ) -> (u32, bool)
pub(crate) fn empty(def: GenericDefId) -> Self
👎Deprecated:
don’t use this; it’s easy to expose an erroneous Generics with this
fn opaque_lifetime_idx(&self, param: LifetimeParamId) -> usize